@@ -65,7 +65,7 @@ where
         .map_err(|e| {
             Error::registry(std::str::from_utf8(e.data().unwrap_or(&[])).unwrap_or_default())
         })?;
-    rmp_serde::from_read_ref(result.payload()).map_err(Into::into)
+    rmp_serde::from_slice(result.payload()).map_err(Into::into)
 }
 
 #[derive(Serialize)]
